# Creating and Managing S-Users in SAP For Me
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#prerequisites)
  * [Creating S-User IDs](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#creating-s-user-ids)
  * [Deleting S-User IDs](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#deleting-s-user-ids)
  * [Editing S-User ID Authorizations](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#editing-s-user-id-authorizations)
  * [Creating Authorization Packages](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#creating-authorization-packages)
  * [Cloning S-User ID Authorizations](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#cloning-s-user-id-authorizations)
  * [Troubleshooting](https://help.sap.com/docs/leanix/ea/creating-and-managing-s-users-in-sap-for-me#troubleshooting)


This guide describes how to create, manage, and troubleshoot S-user IDs to enable seamless access to SAP for Me.
